@@ -1336,7 +1336,7 @@ START_TEST(test_concat)
 
    input_from_file(TESTDIR "/simp/concat.vhd");
 
-   tree_t p = parse_check_and_simplify(T_PACKAGE);
+   tree_t p = parse_check_and_simplify(T_PACKAGE, T_PACKAGE);
 
    static const char *strings[] = {
       "100", "xyz", "10", "foo"
@@ -1358,7 +1358,7 @@ START_TEST(test_concat)
       }
    }
 
-   static const assoc_kind_t concat[][5] = {
+   static const assoc_kind_t concat[][6] = {
       { A_POS, A_POS, -1 },
       { A_POS, A_POS, A_POS, -1 },
       { A_CONCAT, A_POS, -1 },
@@ -1366,6 +1366,7 @@ START_TEST(test_concat)
       { A_POS, A_CONCAT, -1 },
       { A_CONCAT, A_CONCAT, -1 },
       { A_POS, A_POS, A_POS, A_POS, -1 },
+      { A_POS, A_POS, -1 },
     };
 
    for (int i = 0; i < ARRAY_LEN(concat); i++) {
@@ -1919,6 +1920,29 @@ START_TEST(test_issue1239)
 }
 END_TEST
 
+START_TEST(test_issue1318)
+{
+   set_standard(STD_08);
+
+   input_from_file(TESTDIR "/parse/issue1318.vhd");
+
+   tree_t a = parse_check_and_simplify(T_ENTITY, T_ARCH);
+   tree_t d = get_decl(a, "CONST_USING_BUS_ARRAY");
+
+   tree_t r = range_of(tree_type(d), 0);
+   fail_unless(tree_subkind(r) == RANGE_DOWNTO);
+
+   int64_t low, high;
+   fail_unless(folded_bounds(r, &low, &high));
+   fail_unless(low == 0);
+   fail_unless(high == 31);
+
+   fail_unless(parse() == NULL);
+
+   fail_if_errors();
+}
+END_TEST
+
 Suite *get_simp_tests(void)
 {
    Suite *s = suite_create("simplify");
@@ -1993,6 +2017,7 @@ Suite *get_simp_tests(void)
    tcase_add_test(tc_core, test_genpack2);
    tcase_add_test(tc_core, test_issue1182);
    tcase_add_test(tc_core, test_issue1239);
+   tcase_add_test(tc_core, test_issue1318);
    suite_add_tcase(s, tc_core);
 
    return s;
